import { ParamCalculability } from "../param/param-definition";
import { StructureWeirSubmergedLarinier } from "../structure/structure_weir_submerged_larinier";
import { Result } from "../util/result";
import { CloisonsFenteParams } from "./cloisons_fente_params";

export { CloisonsFenteParams };

/**
 * Equation de la fente noyé pour l'outil "Cloisons"
 * d'après Larinier, M., Travade, F., Porcher, J.-P., Gosset, C., 1992.
 * Passes à poissons : expertise et conception des ouvrages de franchissement
 */
export class CloisonsFente extends StructureWeirSubmergedLarinier {

    constructor(prms: CloisonsFenteParams, dbg: boolean = false) {
        super(prms, dbg);
        this._isZDVcalculable = false;
    }

    /**
     * paramètres castés au bon type
     */
    get prms(): CloisonsFenteParams {
        return this._prms as CloisonsFenteParams;
    }

    /**
     * Calcul analytique Q = f(Cd, L, h1, h2, W) seuil dénoyé
     * @param sVarCalc Variable à calculer (doit être "Q")
     */
    public Equation(sVarCalc: string): Result {
        return super.Equation(sVarCalc);
    }

    /**
     * paramétrage de la calculabilité des paramètres
     */
    protected setParametersCalculability() {
        super.setParametersCalculability();
        this.prms.H1.calculability = ParamCalculability.DICHO;
        this.prms.DH.calculability = ParamCalculability.DICHO;
        this.prms.Z2.calculability = ParamCalculability.FREE;
        this.prms.ZDV.calculability = ParamCalculability.FREE;
    }
}
