import { ParamDefinition } from "../param/param-definition";
import { ParamDomainValue } from "../param/param-domain";
import { RectangularStructureParams } from "../structure/rectangular_structure_params";

/**
 * Parameters for rectangular structures (common for all rectangular structure equations)
 */
export class CloisonsFenteParams extends RectangularStructureParams {
    /** Head (m) */
    public H1: ParamDefinition;

    /** Drop (m) */
    public DH: ParamDefinition;

    /**
     * Constructeur d'une structure rectangulaire
     * @param rQ    Débit (m3/s)
     * @param rZ1   Cote de l'eau amont (m)
     * @param rH1   Charge amont sur la fente (m)
     * @param rDH   Chute (m)
     * @param rL    Largeur de la fente (m)
     * @param rCd   Coefficient de débit (-)
     */
    constructor(
        rQ: number, rZ1: number, rH1: number, rDH: number,
        rL: number, rCd: number
    ) {
        super(rQ, rZ1 - rH1, rZ1, - Infinity, rL, rCd);
        this.H1 = new ParamDefinition("H1", ParamDomainValue.POS_NULL, rH1);
        this.addParamDefinition(this.H1);
        this.DH = new ParamDefinition("DH", ParamDomainValue.POS_NULL, rDH);
        this.addParamDefinition(this.DH);
        this.Cd = new ParamDefinition("Cd", ParamDomainValue.POS, rCd);
        this.addParamDefinition(this.Cd);
    }

    public update_h1h2() {
        this.ZDV.v = this.Z1.v - this.H1.v;
        this.Z2.v = this.Z1.v - this.DH.v;
        super.update_h1h2();
    }
}
