import { ParamDefinition } from "../param/param-definition";
import { ParamDomainValue } from "../param/param-domain";
import { StructureParams } from "../structure/structure_params";

/**
 * Parameters for rectangular structures (common for all rectangular structure equations)
 */
export class CloisonsOrificeParams extends StructureParams {

    /** Drop (m) */
    public DH: ParamDefinition;

    /** Area of the orifice (m2) */
    public S: ParamDefinition;

    /** Discharge coefficient */
    // tslint:disable-next-line:variable-name
    public Cd: ParamDefinition;

    /**
     * Constructeur d'une structure rectangulaire
     * @param rQ    Débit (m3/s)
     * @param rZ1   Cote de l'eau amont (m)
     * @param rDH   Chute (m)
     * @param rCd   Coefficient de débit (-)
     * @param rS    Surface de l'orifice (m2)
     */
    constructor(rQ: number, rZ1: number, rDH: number, rCd: number, rS: number) {
        super(rQ, -Infinity, rZ1, rZ1 - rDH);
        this.DH = new ParamDefinition("DH", ParamDomainValue.POS_NULL, rDH);
        this.addParamDefinition(this.DH);
        this.S = new ParamDefinition("S", ParamDomainValue.POS_NULL, rS);
        this.addParamDefinition(this.S);
        this.Cd = new ParamDefinition("Cd", ParamDomainValue.POS_NULL, rCd);
        this.addParamDefinition(this.Cd);
    }

    /**
     * Mise à jour de h1 et h2
     */
    public update_h1h2() {
        // Inutile pour cette équation qui ne fait pas intervenir ces variables
    }

}
