import { Nub } from "../nub";
import { ParamCalculability, ParamDefinition } from "../param/param-definition";
import { ParamDomainValue } from "../param/param-domain";
import { ParamsEquation } from "../param/params-equation";
import { Result } from "../util/result";

export class PabPuissanceParams extends ParamsEquation {
    [key: string]: any; // pour pouvoir faire this['methode]();

    /** Chute entre bassins DH */
    private _DH: ParamDefinition;

    /** Débit Q */
    private _Q: ParamDefinition;

    /** Volume V */
    private _V: ParamDefinition;

    /** Puissance dissipée PV */
    private _Pv: ParamDefinition;

    constructor(rDH: number, rQ: number, rV: number, rPV?: number) {
        super();
        this._DH = new ParamDefinition("DH", ParamDomainValue.POS, rDH);
        this._Q = new ParamDefinition("Q", ParamDomainValue.POS, rQ);
        this._V = new ParamDefinition("V", ParamDomainValue.POS, rV);
        this._Pv = new ParamDefinition("Pv", ParamDomainValue.POS, rPV);

        this.addParamDefinition(this._DH);
        this.addParamDefinition(this._Q);
        this.addParamDefinition(this._V);
        this.addParamDefinition(this._Pv);
    }

    get DH() {
        return this._DH;
    }

    get Q() {
        return this._Q;
    }

    get V() {
        return this._V;
    }

    get Pv() {
        return this._Pv;
    }
}

// tslint:disable-next-line:max-classes-per-file
export class PabPuissance extends Nub {
    constructor(prms: PabPuissanceParams, dbg: boolean = false) {
        super(prms, dbg);
    }

    /**
     * paramètres castés au bon type
     */
    get prms(): PabPuissanceParams {
        return this._prms as PabPuissanceParams;
    }

    public Equation(sVarCalc: string): Result {
        let v: number;

        switch (sVarCalc) {
            case "Pv":
                const ro: number = 1000;     // masse volumique de l'eau en kg/m3
                const g: number = 9.81;     // accélération de la gravité terrestre en m/s2.
                v = ro * g * this.prms.Q.v * this.prms.DH.v / this.prms.V.v;
                break;

            default:
                throw new Error("PabPuissance.Equation() : invalid variable name " + sVarCalc);
        }

        return new Result(v);
    }

    /**
     * paramétrage de la calculabilité des paramètres
     */
    protected setParametersCalculability() {
        this.prms.DH.calculability = ParamCalculability.DICHO;
        this.prms.Q.calculability = ParamCalculability.DICHO;
        this.prms.V.calculability = ParamCalculability.DICHO;
        this.prms.Pv.calculability = ParamCalculability.EQUATION;
    }

}
