export enum StructureType {
    SeuilRectangulaire, VanneRectangulaire, SeuilTriangulaire, SeuilTriangulaireTrunc
    // VanneCirculaire,
    // VanneTrapezoidale, SeuilTrapezoidal
}

export enum LoiDebit {
    // loi de débit Déversoir / Orifice Cemagref 1988
    Cem88d,
    // loi de débit Déversoir / Vanne de fond Cemagref 1988
    Cem88v,
    // loi de débit Cunge 1980
    Cunge80,
    // loi de débit pour vanne dénoyée
    OrificeFree,
    // loi de débit pour vanne noyée
    OrificeSubmerged,
    // loi de débit pour seuil dénoyé
    WeirFree,
    // Loi Kindsvater-Carter et Villemonte
    KIVI,
    // Loi de débit seuil triangulaire dénoyé
    TriangularWeirFree,
    // Loi de débit seuil triangulaire tronqué
    TriangularTruncWeirFree,
    // Loi de débit seuil noyé (Larinier 1992)
    WeirSubmergedLarinier
}

export const loiAdmissibles: { [key: string]: LoiDebit[] } = {
    SeuilRectangulaire: [
        LoiDebit.Cem88d, LoiDebit.Cem88v, LoiDebit.Cunge80, LoiDebit.WeirFree,
        LoiDebit.KIVI, LoiDebit.WeirSubmergedLarinier
    ],
    SeuilTriangulaire: [
        LoiDebit.TriangularWeirFree
    ],
    SeuilTriangulaireTrunc: [
        LoiDebit.TriangularTruncWeirFree
    ],
    VanneRectangulaire: [
        LoiDebit.Cem88d, LoiDebit.Cem88v, LoiDebit.Cunge80, LoiDebit.OrificeFree,
        LoiDebit.OrificeSubmerged
    ]
};

export class StructureProperties {
    /**
     * @return true si les valeurs de StructureType et LoiDebit sont compatibles
     */
    public static isCompatibleValues(struct: StructureType, loi: LoiDebit): boolean {
        return loiAdmissibles[StructureType[struct]].includes(loi);
    }

    /**
     * @return la 1ère valeur de StructureType compatible avec la loi de débit
     */
    public static findCompatibleStructure(loi: LoiDebit): StructureType {
        for (const st in loiAdmissibles) {
            if (loiAdmissibles.hasOwnProperty(st)) {
                const lds: LoiDebit[] = loiAdmissibles[st];
                for (const ld of lds) {
                    if (ld === loi) { return (StructureType as any)[st]; }
                }
            }
        }
        return undefined;
    }

    /**
     * @return la 1ère valeur de LoiDebit compatible avec le type de structure
     */
    public static findCompatibleLoiDebit(struct: StructureType): LoiDebit {
        const sst: string = StructureType[struct];
        return loiAdmissibles[sst][0];
    }
}
